@@ -4,21 +4,18 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-/**
- * SECTION:fwupd
- * @short_description: Helper objects for accessing fwupd
- */
-
-#ifndef __FWUPD_H__
-#define __FWUPD_H__
+#pragma once
 
 #define __FWUPD_H_INSIDE__
 
 #include <libfwupd/fwupd-client.h>
+#include <libfwupd/fwupd-client-sync.h>
 #include <libfwupd/fwupd-common.h>
 #include <libfwupd/fwupd-device.h>
+#include <libfwupd/fwupd-plugin.h>
 #include <libfwupd/fwupd-enums.h>
 #include <libfwupd/fwupd-error.h>
+#include <libfwupd/fwupd-security-attr.h>
 #include <libfwupd/fwupd-release.h>
 #include <libfwupd/fwupd-remote.h>
 #include <libfwupd/fwupd-version.h>
@@ -28,6 +25,3 @@
 #endif
 
 #undef __FWUPD_H_INSIDE__
-
-#endif /* __FWUPD_H__ */
-
